@@ -1,16 +1,15 @@
-__version__ = '0.0.13'
+__version__ = '0.0.23'
 __usage__ = """
     USAGE:
-        As a module from any location
-            python3 -m myhttps [-option value]
+        myhttps [-option value]
 
     OPTIONS:
-        --v             Version Info(**)
-        --help          Help and usage Info(**)
         -p              Port Number [default: 11443]
         -h              Host address
         -c              ssl cert file location
         -k              ssl key file location
         -mode           HTTPS or HTTP
-
+        -url            url to download
+        -outdir         output directory
+        -d              share directory
 """
